You are viewing a plain text version of this content. The canonical link for it is here.
Posted to derby-commits@db.apache.org by fu...@apache.org on 2007/03/08 23:25:48 UTC

svn commit: r516196 [3/3] - in /db/derby/code/trunk/java/engine/org/apache/derby/impl: jdbc/ jdbc/authentication/ load/ services/bytecode/ services/cache/ services/jce/ services/locks/ services/monitor/ services/reflect/ sql/ sql/catalog/ sql/compile/ ...

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StoredPage.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StoredPage.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StreamFileContainerHandle.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StreamFileContainerHandle.java Thu Mar  8 14:25:41 2007
@@ -190,7 +190,7 @@
 	/**
 		remove the stream container
 
-		@exception StandardException Standard Cloudscape error policy		
+		@exception StandardException Standard Derby error policy		
 		@see StreamContainerHandle#removeContainer
 	 */
 	public void removeContainer() throws StandardException {
@@ -257,14 +257,14 @@
 	** in other packages that are specific implementations of Data, ie.
 	** a directory at the level
 	**
-	** com.ibm.db2j.impl.Database.Storage.RawStore.Data.*
+	** org.apache.derby.impl.store.raw.data.*
 	*/
 
 	/**
 		Attach me to a container. If this method returns false then
 		I cannot be used anymore, and any reference to me must be discarded.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public boolean useContainer() throws StandardException {
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SyncOnCommit.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SyncOnCommit.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SyncOnCommit.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/SyncOnCommit.java Thu Mar  8 14:25:41 2007
@@ -72,7 +72,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected void doIt(BaseContainerHandle handle)
 		throws StandardException {

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TempRAFContainer.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TempRAFContainer.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TempRAFContainer.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TempRAFContainer.java Thu Mar  8 14:25:41 2007
@@ -58,7 +58,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Cacheable setIdentity(Object key) throws StandardException {
 
@@ -74,7 +74,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Cacheable createIdentity(Object key, Object createParameter) throws StandardException {
 
@@ -89,7 +89,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void removeContainer(LogInstant instant, boolean leaveStub) throws StandardException
 	{
@@ -122,7 +122,7 @@
 		Write the page, if it's within range of the current page range of the container.
 		If we do write it then don't request that it be synced.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void writePage(long pageNumber, byte[] pageData, boolean syncPage) throws IOException, StandardException {
 		if (!this.getDroppedState()) {
@@ -148,7 +148,7 @@
 		Add a page without locking the container, only one user will be accessing this
 		table at a time.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public Page addPage(BaseContainerHandle handle, boolean isOverflow) throws StandardException {
 
@@ -162,7 +162,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void truncate(BaseContainerHandle handle) throws StandardException {
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TruncateOnCommit.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TruncateOnCommit.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TruncateOnCommit.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/TruncateOnCommit.java Thu Mar  8 14:25:41 2007
@@ -84,7 +84,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void doIt(BaseContainerHandle handle)
 		throws StandardException {

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateFieldOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateFieldOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateOperation.java Thu Mar  8 14:25:41 2007
@@ -316,7 +316,7 @@
 	/**
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FileLogger.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FileLogger.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FileLogger.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FileLogger.java Thu Mar  8 14:25:41 2007
@@ -197,7 +197,7 @@
 		@return the instant in the log that can be used to identify the log
 		record
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	*/
 	public synchronized LogInstant logAndDo(RawTransaction xact, Loggable operation) 
 		 throws StandardException 
@@ -446,7 +446,7 @@
 		@return the instant in the log that can be used to identify the log
 		record
 
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	public LogInstant logAndUndo(RawTransaction xact, 
 								 Compensation compensation,
@@ -855,7 +855,7 @@
 		@param undoStopAt	the last log record that should be rolled back
 		@param undoStartAt	the first log record that should be rolled back
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 
 		@see Logger#undo
 	  */
@@ -1112,7 +1112,7 @@
 		after the last log record).  This is used to determine where the log
 		truly ends
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException error reading log file
 		@exception ClassNotFoundException log file corrupted
 
@@ -1599,7 +1599,7 @@
 		more log operation in the log scan
 
 		@exception IOException	Error reading the log file
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception ClassNotFoundException log corrupted
 	 */
 	protected Loggable readLogRecord(StreamLogScan scan, int size)

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FlushedScan.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FlushedScan.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FlushedScan.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/FlushedScan.java Thu Mar  8 14:25:41 2007
@@ -119,7 +119,7 @@
 		@return the length of the data written into data, or -1 if the end of the
 		scan has been reached.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public LogRecord getNextRecord(ArrayInputStream input, 
 								   TransactionId tranId, 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogAccessFile.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogAccessFile.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogAccessFile.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogAccessFile.java Thu Mar  8 14:25:41 2007
@@ -704,7 +704,7 @@
             {
 
                 // Try to handle case where user application is throwing
-                // random interrupts at cloudscape threads, retry in the case
+                // random interrupts at Derby threads, retry in the case
                 // of IO exceptions 5 times.  After that hope that it is 
                 // a real disk problem - an IO error in a write to the log file
                 // is going to take down the whole system, so seems worthwhile

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/Scan.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/Scan.java Thu Mar  8 14:25:41 2007
@@ -111,7 +111,7 @@
 		   first not-flushed log record. Like any forward scan, we expect a scan
 		   positioned at the beginning of the next log record.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException cannot access the log at the new position.
 	*/
 	public Scan(LogToFile logFactory, long startAt, LogInstant stopAt, byte direction)
@@ -184,7 +184,7 @@
 		@return the next LogRecord, or null if the end of the
 		scan has been reached.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public LogRecord getNextRecord(ArrayInputStream input, 
 							 TransactionId tranId, 
@@ -1087,7 +1087,7 @@
 
 		@param instant the position to reset to
 		@exception IOException scan cannot access the log at the new position.
-		@exception StandardException cloudscape standard error policy
+		@exception StandardException standard Derby error policy
 	*/
 
 	public void resetPosition(LogInstant instant) 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking2.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking2.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking2.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking2.java Thu Mar  8 14:25:41 2007
@@ -55,7 +55,7 @@
 		Obtain a Container shared or exclusive lock	until
 		the end of the nested transaction.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public boolean lockContainer(
     Transaction     t, 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking3.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking3.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking3.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/ContainerLocking3.java Thu Mar  8 14:25:41 2007
@@ -50,7 +50,7 @@
 		Obtain a Container shared or exclusive lock	until
 		the end of the nested transaction.
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public boolean lockContainer(
     Transaction     t, 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/D_Xact.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/D_Xact.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/D_Xact.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/D_Xact.java Thu Mar  8 14:25:41 2007
@@ -48,7 +48,7 @@
      * <p>
      *
 	 * @return A string with diagnostic information about the object.
-     * @exception StandardException Standard Cloudscape Error
+     * @exception StandardException Standard Derby Error
      *
      **/
     public String diag()

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/Xact.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/Xact.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/Xact.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/Xact.java Thu Mar  8 14:25:41 2007
@@ -363,7 +363,7 @@
 
 		@see RawTransaction#logAndDo 
 		
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	*/
 	public void logAndUndo(Compensation compensation, LogInstant undoInstant, LimitObjectInput in)
 		 throws StandardException
@@ -525,7 +525,7 @@
 
 	/**
 		The default value for LOCKS_ESCALATION_THRESHOLD
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 	 */
 	public void setup(PersistentSet set)
 		throws StandardException {
@@ -651,7 +651,7 @@
 	}
 	
 	/** 
-	  @exception StandardException  Standard cloudscape exception policy
+	  @exception StandardException  Standard Derby exception policy
 	*/
 	public LogInstant commit() throws StandardException
 	{
@@ -659,7 +659,7 @@
 	}
 
 	/** 
-	  @exception StandardException  Standard cloudscape exception policy
+	  @exception StandardException  Standard Derby exception policy
 	*/
 	public LogInstant commitNoSync(int commitflag) throws StandardException
 	{
@@ -697,7 +697,7 @@
 	}
 
 	/** 
-	  @exception StandardException  Standard cloudscape exception policy
+	  @exception StandardException  Standard Derby exception policy
 	  @see Transaction#commit
 	*/
 
@@ -846,7 +846,7 @@
 	}
 
 	/** 
-	  @exception StandardException  Standard cloudscape exception policy
+	  @exception StandardException  Standard Derby exception policy
 	  @see Transaction#commit
 	*/
 	private LogInstant commit(int commitflag) 
@@ -867,7 +867,7 @@
 
 
 	/** 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#abort
 	*/
 	public void abort() throws StandardException {
@@ -1073,7 +1073,7 @@
 	/**
         If this transaction is not idle, abort it.  After this call close().
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
         Thrown if the transaction is not idle.
 
 		
@@ -1087,12 +1087,12 @@
     }
 
 	/**
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@exception StandardException Thrown if the transaction is not idle, the
 		transaction remains open.
 		@see Transaction#close
 
-		@exception StandardException	Standard cloudscape policy
+		@exception StandardException	Standard Derby policy
 	*/
 	public void close() throws StandardException {
 
@@ -1168,7 +1168,7 @@
 		If the passed in operation is null, then do nothing (after logging the
 		beginXact if needed).
 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#logAndDo 
 	*/
 	public void logAndDo(Loggable operation) throws StandardException {
@@ -1251,7 +1251,7 @@
 		Return a record handle that is initialized to the given page number and
         record id.
 
-		@exception StandardException Standard cloudscape exception policy.
+		@exception StandardException Standard Derby exception policy.
 
 		@param segmentId    segment where the RecordHandle belongs.
 		@param containerId  container where the RecordHandle belongs.
@@ -1268,7 +1268,7 @@
 //     }
 
 	/** 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#openContainer 
 	*/
 	public ContainerHandle openContainer(ContainerKey containerId,  int mode)
@@ -1278,7 +1278,7 @@
 	}
 
 	/** 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#openContainer 
 	*/
 	public ContainerHandle openContainer(ContainerKey containerId, LockingPolicy locking, int mode)
@@ -1295,7 +1295,7 @@
 	/**
 		Open a container that may already have been dropped.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 		@see RawTransaction#openDroppedContainer
 	*/
 	public RawContainerHandle openDroppedContainer(ContainerKey containerId, LockingPolicy locking)
@@ -1327,7 +1327,7 @@
 
 
 	/** 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#addContainer 
 	*/
 	public long addContainer(long segmentId, long containerid, int mode, Properties tableProperties, int temporaryFlag)
@@ -1339,7 +1339,7 @@
 	}
 
 	/** 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#addAndLoadStreamContainer
 	*/
 	public long addAndLoadStreamContainer(long segmentId, Properties tableProperties, RowSource rowSource)
@@ -1352,7 +1352,7 @@
 	}
 
 	/** 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#openStreamContainer
 	*/
 	public StreamContainerHandle openStreamContainer(
@@ -1370,7 +1370,7 @@
 
 	/**
 		@see Transaction#dropStreamContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void dropStreamContainer(long segmentId, long containerId)
 		throws StandardException {
@@ -1387,7 +1387,7 @@
         are trying to create a container, and no valid container is found
         in the database.
 
-		@exception StandardException  Standard cloudscape exception policy
+		@exception StandardException  Standard Derby exception policy
 		@see RawTransaction#reCreateContainerForRedoRecovery
 	 */
 	public void reCreateContainerForRedoRecovery
@@ -1402,7 +1402,7 @@
 
 	/**
 		@see Transaction#dropContainer
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void dropContainer(ContainerKey containerId)
 		throws StandardException {
@@ -1413,7 +1413,7 @@
 	}
 
 	/**
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#setSavePoint
 	*/
 	public int setSavePoint(String name, Object kindOfSavepoint) 
@@ -1458,7 +1458,7 @@
     // defined in the transaction. If yes, then throw an exception
 
 	/**
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#setSavePoint
 	*/
 	private void throwExceptionIfSQLSavepointNotAllowed(Object kindOfSavepoint)
@@ -1486,7 +1486,7 @@
 	}
 
 	/**
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#releaseSavePoint
 	*/
 	public int releaseSavePoint(String name, Object kindOfSavepoint) 
@@ -1517,7 +1517,7 @@
 	}
 
 	/** 
-	    @exception StandardException  Standard cloudscape exception policy
+	    @exception StandardException  Standard Derby exception policy
 		@see Transaction#rollbackToSavePoint
 	*/
 	public int rollbackToSavePoint(String name, Object kindOfSavepoint) 
@@ -2154,7 +2154,7 @@
 		otherwise it is left in the stack (at the top).
 
 		@return true if any work is rolled back, false if no work is rolled back
-		@exception StandardException	Standard cloudscape policy
+		@exception StandardException	Standard Derby policy
 		@exception StandardException Thrown if a error of severity less than TransactionException#SEVERITY
 		is encountered during the rollback of this savepoint.
 	*/
@@ -2207,7 +2207,7 @@
 	}
 
 	/**
-		@exception StandardException Cloudscape Standard error policy
+		@exception StandardException Derby Standard error policy
 	 */
 	public RawTransaction startNestedTopTransaction() throws StandardException {
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactContext.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactContext.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactContext.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactContext.java Thu Mar  8 14:25:41 2007
@@ -67,7 +67,7 @@
 
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void cleanupOnError(Throwable error) throws StandardException {
 

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactFactory.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactFactory.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StoredPage.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StoredPage.java Thu Mar  8 14:25:41 2007
@@ -1407,7 +1407,7 @@
      * @return  false if a qualifier_list is provided and the row does not 
      *          qualifier (no row read in that case), else true.
      *
      * @exception StandardException	Standard Cloudscape error policy
      **/
 	protected boolean restoreRecordFromSlot(
     int                     slot, 
@@ -3189,7 +3189,7 @@
 
 		@param slot the slot number where the current piece of overflow column
 		is at.
-		@exception StandardException Cloudscape Standard Error Policy
+		@exception StandardException Derby Standard Error Policy
 	 */
     /**
      * Return the next recordHandle in a long column chain.
@@ -3546,7 +3546,7 @@
 
 		<P>
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 
 	*/
@@ -4307,7 +4307,7 @@
 		@param limitInput the limit input stream
 		@param objectInput the object input stream
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException  I/O exception in reading meta data.
 	*/
 
@@ -5858,7 +5858,7 @@
      * field header followed the data of the column as defined by the data 
      * itself.  See this class's description for the specifics of the header.
      *
      * @exception StandardException	    Standard Cloudscape error policy
      * @exception IOException			RESOLVE
      **/
 	public void logColumn(
@@ -5930,7 +5930,7 @@
      * @param column    the object form of the column to log 
      * @param out       where to log to the column to.
      *
      * @exception StandardException	Standard Cloudscape error policy
      * @exception IOException	    I/O exception from writing to an array.
      *
      * @see BasePage#logColumn
@@ -6516,7 +6516,7 @@
      * preceeded by a  compressed int that gives the length of the following 
      * data.
      *
      * @exception StandardException	Standard Cloudscape error policy
      * @exception IOException	    on error writing to log stream.
      *
      * @see BasePage#logRecord
@@ -6664,7 +6664,7 @@
 		Find the field in the record and then write out the complete
 		field, i.e. header and data.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 
 		@see BasePage#logField
@@ -6697,7 +6697,7 @@
 
 	/**
 		Override insertAtSlot to provide long row support.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public RecordHandle insertAtSlot(
     int                   slot, 
@@ -6729,7 +6729,7 @@
 
 	/**
 		Update field at specified slot
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public RecordHandle updateFieldAtSlot(
     int                 slot, 
@@ -6766,7 +6766,7 @@
 
 	/**
 		Get the number of fields on the row at slot
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public int fetchNumFieldsAtSlot(int slot) throws StandardException
 	{
@@ -6820,7 +6820,7 @@
      *
      * @return the number of rows processed.
      *
      * @exception StandardException	Standard Cloudscape error policy
      *
      **/
 	public int moveRecordForCompressAtSlot(
@@ -6973,7 +6973,7 @@
 		which may or may not be cleaned up the the client of raw store when it 
         was deallocated.
 
-		@exception StandardException Cloudscape Standard Error Policy
+		@exception StandardException Derby Standard Error Policy
 	 */
 	public void initPage(LogInstant instant, byte status, int recordId, 
 						 boolean overflow, boolean reuse)
@@ -7000,7 +7000,7 @@
 
 	/**
 		Set page status
-		@exception StandardException Cloudscape Standard Error Policy
+		@exception StandardException Derby Standard Error Policy
 	*/
 	public void setPageStatus(LogInstant instant, byte status)
 		 throws StandardException
@@ -7014,7 +7014,7 @@
 
 	/**
 		Set the row reserved space.
-		@exception StandardException Cloudscape Standard Error Policy
+		@exception StandardException Derby Standard Error Policy
 	 */
 	public void setReservedSpace(LogInstant instant, int slot, int value)
 		 throws StandardException, IOException
@@ -7061,7 +7061,7 @@
 	/**
 		Store a record at the given slot.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 	*/
 	public void storeRecord(LogInstant instant, int slot, boolean insert, ObjectInput in)
@@ -7506,7 +7506,7 @@
 		when this method returns, ie. it only moves data that
 		has an offset greater then this.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 	*/
 	private void createSpaceForUpdate(int slot, int offset, int oldLength, int newLength)
@@ -7610,7 +7610,7 @@
 	/**
 		storeField
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 	*/
 	public void storeField(LogInstant instant, int slot, int fieldNumber, ObjectInput in)
@@ -7647,7 +7647,7 @@
 		This method will reserve at least specified "spaceToReserve" bytes for the record
 		in the slot.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 	*/
 	public void reserveSpaceForSlot(LogInstant instant, int slot, int spaceToReserve)
@@ -7745,7 +7745,7 @@
 	/**
 		Set the deleted status
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 		@see BasePage#setDeleteStatus
 	*/
@@ -7776,7 +7776,7 @@
 	/**
 		purgeRecord from page.  Move following slots up by one.
 
-		@exception StandardException	Standard Cloudscape error policy
+		@exception StandardException	Standard Derby error policy
 		@exception IOException			RESOLVE
 	*/
 	public void purgeRecord(LogInstant instant, int slot, int recordId)
@@ -8097,7 +8097,7 @@
 
 	/**
 		Get the overflow page for a record that has already overflowed.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected StoredPage getOverflowPage(long pageNumber) throws StandardException
 	{
@@ -8116,7 +8116,7 @@
 
 	/**
 		Get an empty overflow page.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected BasePage getNewOverflowPage() throws StandardException
 	{
@@ -8133,7 +8133,7 @@
 
 	/**
 		Get the overflow slot for a record that has already overflowed.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected static int getOverflowSlot(BasePage overflowPage, StoredRecordHeader recordHeader)
 		throws StandardException
@@ -8153,7 +8153,7 @@
 
 	/**
 		Get a overflow page that potentially can handle a new overflowed record.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public BasePage getOverflowPageForInsert(
     int                     currentSlot, 
@@ -8165,7 +8165,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public BasePage getOverflowPageForInsert(
     int                     currentSlot, 
@@ -8251,7 +8251,7 @@
 		@param slot Slot of the original record on its original page
 		@param row new version of the data
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected void updateOverflowed(
     RawTransaction          t, 
@@ -8286,7 +8286,7 @@
 	/**
 		Update a record handle to point to an overflowed record portion.
 		Note that the record handle need not be the current page.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void updateOverflowDetails(RecordHandle handle, RecordHandle overflowHandle)
 		throws StandardException
@@ -8322,7 +8322,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void updateFieldOverflowDetails(RecordHandle handle, RecordHandle overflowHandle)
 		throws StandardException
@@ -8346,7 +8346,7 @@
 	}
 
 	/**
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public int appendOverflowFieldHeader(DynamicByteArrayOutputStream logBuffer, RecordHandle overflowHandle)
 		throws StandardException, IOException
@@ -8423,7 +8423,7 @@
 	/**
 		Perform an update.
 
-		@exception StandardException Standard cloudscape policy
+		@exception StandardException Standard Derby policy
 	*/
 	public void doUpdateAtSlot(
     RawTransaction          t, 
@@ -8880,7 +8880,7 @@
 
 	/**
 		@see BasePage#compactRecord
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	 */
 	protected void compactRecord(RawTransaction t, int slot, int id) 
 		 throws StandardException 
@@ -1407,7 +1407,7 @@
      *          qualifier (no row read in that case), else true.
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      **/
 	protected boolean restoreRecordFromSlot(
@@ -5858,7 +5858,7 @@
      * itself.  See this class's description for the specifics of the header.
      *
-     * @exception StandardException	    Standard Cloudscape error policy
+     * @exception StandardException	    Standard Derby error policy
      * @exception IOException			RESOLVE
      **/
@@ -5930,7 +5930,7 @@
      * @param out       where to log to the column to.
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      * @exception IOException	    I/O exception from writing to an array.
      *
@@ -6516,7 +6516,7 @@
      * data.
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      * @exception IOException	    on error writing to log stream.
      *
@@ -6820,7 +6820,7 @@
      * @return the number of rows processed.
      *
-     * @exception StandardException	Standard Cloudscape error policy
+     * @exception StandardException	Standard Derby error policy
      *
      **/

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StreamFileContainerHandle.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/StreamFileContainerHandle.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateFieldOperation.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateFieldOperation.java Thu Mar  8 14:25:41 2007
@@ -148,7 +148,7 @@
 		Change the value of a field.
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 		@see org.apache.derby.iapi.store.raw.Loggable#doMe
 	*/
@@ -166,7 +166,7 @@
 		Restore field to its old value.
 
 		@exception IOException Can be thrown by any of the methods of ObjectInput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 
 		@see LogicalPageOperation#undoMe
 	*/
@@ -213,7 +213,7 @@
 		Restore the row stored in the optional data of the log record.
 
 		@exception IOException error reading from log stream
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void restoreLoggedRow(Object[] row, LimitObjectInput in)
 		throws StandardException, IOException
@@ -255,7 +255,7 @@
 	/**
 	 * restore the before image of the page
 	 *
 	 * @exception StandardException Standard Cloudscape Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream
 	 */
@@ -298,7 +298,7 @@
 	  If logical undo, writes out the entire row's before image.
 
 		@exception IOException Can be thrown by any of the methods of ObjectOutput.
-		@exception StandardException Standard Cloudscape policy.
+		@exception StandardException Standard Derby policy.
 	*/
 	private void writeOptionalDataToBuffer(
     RawTransaction      t, 
@@ -255,7 +255,7 @@
 	 * restore the before image of the page
 	 *
-	 * @exception StandardException Standard Cloudscape Error Policy
+	 * @exception StandardException Standard Derby Error Policy
 	 * @exception IOException problem reading the complete log record from the
 	 * input stream

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateOperation.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/data/UpdateOperation.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/LogToFile.java Thu Mar  8 14:25:41 2007
@@ -584,7 +584,7 @@
 		@see Loggable#needsRedo
 		@see FileLogger#redo
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void recover(
     RawStoreFactory     rsf, 
@@ -1389,7 +1389,7 @@
 	/**
 		checkpoint with pre-start transaction
 
-		@exception StandardException Cloudscape Standard Error Policy 
+		@exception StandardException Derby Standard Error Policy 
 	*/
 	protected boolean checkpointWithTran(RawTransaction cptran, 
 							   RawStoreFactory rsf,
@@ -1628,7 +1628,7 @@
 
 		@param where flush log up to here
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void flush(LogInstant where) throws StandardException
 	{
@@ -1654,7 +1654,7 @@
 
 		<P>MT - not needed, wrapper method
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	public void flushAll() throws StandardException
 	{
@@ -1685,7 +1685,7 @@
 		@return true if the log file is of the current version and of the
 		correct format
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	private boolean verifyLogFormat(StorageFile logFileName, long number)
 		 throws StandardException 
@@ -1717,7 +1717,7 @@
 		@return true if the log file is of the current version and of the
 		correct format
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	private boolean verifyLogFormat(StorageRandomAccessFile log, long number) 
 		 throws StandardException
@@ -2515,7 +2515,7 @@
 		Return the directory the log should go.
 
 		<P> MT- read only
-		@exception StandardException Cloudscape Standard Error Policy
+		@exception StandardException Derby Standard Error Policy
 	*/
 	public StorageFile getLogDirectory() throws StandardException
 	{
@@ -2615,7 +2615,7 @@
 		<P> MT- read only
 
 		@exception IOException cannot access the log
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected LogScan openBackwardsScan(long startAt, LogInstant stopAt)  
 		 throws IOException, StandardException
@@ -2639,7 +2639,7 @@
 		<P> MT- read only
 
 		@exception IOException cannot access the log
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected LogScan openBackwardsScan(LogInstant stopAt)
 		 throws IOException, StandardException
@@ -2684,7 +2684,7 @@
 			Otherwise, stop at the end of the log
 
 		@exception IOException cannot access the log
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected LogScan openForwardsScan(long startAt, LogInstant stopAt)  
 		 throws IOException, StandardException
@@ -2722,7 +2722,7 @@
 
 		<P> MT- read only
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 		@exception IOException cannot access the log at the new position.
 	*/
 	protected StorageRandomAccessFile getLogFileAtBeginning(long filenumber)
@@ -2741,7 +2741,7 @@
 
 		@return null if file does not exist or of the wrong format
 		@exception IOException cannot access the log at the new position.
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 	*/
 	protected StorageRandomAccessFile getLogFileAtPosition(long logInstant)
 		 throws IOException, StandardException
@@ -3925,7 +3925,7 @@
 	  Open a forward scan of the transaction log.
 
 	  <P> MT- read only
-	  @exception StandardException  Standard cloudscape exception policy
+	  @exception StandardException  Standard Derby exception policy
 	*/
 	public LogScan openForwardsFlushedScan(LogInstant startAt)
 		 throws StandardException
@@ -3941,7 +3941,7 @@
 	/**
 	  Get a forwards scan
 
-	  @exception StandardException Standard Cloudscape error policy
+	  @exception StandardException Standard Derby error policy
 	  */
 	public LogScan openForwardsScan(LogInstant startAt,LogInstant stopAt)
 		 throws StandardException
@@ -4071,7 +4071,7 @@
 
 	/**
 		@see RawStoreFactory#encrypt
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int encrypt(byte[] cleartext, int offset, int length, 
 						  byte[] ciphertext, int outputOffset)
@@ -4083,7 +4083,7 @@
 
 	/**
 		@see RawStoreFactory#decrypt
-		@exception StandardException Standard Cloudscape Error Policy
+		@exception StandardException Standard Derby Error Policy
 	 */
 	public int decrypt(byte[] ciphertext, int offset, int length,
 							 byte[] cleartext, int outputOffset)
@@ -4135,7 +4135,7 @@
 
 	/**
 	 * Backup restore - stop sending log record to the log stream
 	 * @exception StandardException Standard Cloudscape error policy
 	 */
 	public void freezePersistentStore() throws StandardException
 	{
@@ -4149,7 +4149,7 @@
 
 	/**
 	 * Backup restore - start sending log record to the log stream
 	 * @exception StandardException Standard Cloudscape error policy
 	 */
 	public void unfreezePersistentStore() throws StandardException
 	{
@@ -4135,7 +4135,7 @@
 	/**
 	 * Backup restore - stop sending log record to the log stream
-	 * @exception StandardException Standard Cloudscape error policy
+	 * @exception StandardException Standard Derby error policy
 	 */
 	public void freezePersistentStore() throws StandardException
@@ -4149,7 +4149,7 @@
 	/**
 	 * Backup restore - start sending log record to the log stream
-	 * @exception StandardException Standard Cloudscape error policy
+	 * @exception StandardException Standard Derby error policy
 	 */
 	public void unfreezePersistentStore() throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/ReadOnly.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/ReadOnly.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/ReadOnly.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/ReadOnly.java Thu Mar  8 14:25:41 2007
@@ -77,7 +77,7 @@
 
 	/**
 	  MT - not needed, no work is done
-	  @exception StandardException Cloudscape Standard Error Policy
+	  @exception StandardException Standard Derby Error Policy
 	*/
 	public void recover(RawStoreFactory rawStoreFactory,
 						DataFactory dataFactory,
@@ -241,7 +241,7 @@
 
 	/**
 	 * Backup restore - stop sending log record to the log stream
 	 * @exception StandardException Standard Cloudscape error policy
 	 */
 	public void freezePersistentStore() throws StandardException
 	{
@@ -250,7 +250,7 @@
 
 	/**
 	 * Backup restore - start sending log record to the log stream
 	 * @exception StandardException Standard Cloudscape error policy
 	 */
 	public void unfreezePersistentStore() throws StandardException
 	{
@@ -241,7 +241,7 @@
 	/**
 	 * Backup restore - stop sending log record to the log stream
-	 * @exception StandardException Standard Cloudscape error policy
+	 * @exception StandardException Standard Derby error policy
 	 */
 	public void freezePersistentStore() throws StandardException
@@ -250,7 +250,7 @@
 	/**
 	 * Backup restore - start sending log record to the log stream
-	 * @exception StandardException Standard Cloudscape error policy
+	 * @exception StandardException Standard Derby error policy
 	 */
 	public void unfreezePersistentStore() throws StandardException

Modified: db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/Scan.java
URL: http://svn.apache.org/viewvc/db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/log/Scan.java?view=diff&rev=516196&r1=516195&r2=516196
==============================================================================
--- db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactFactory.java (original)
+++ db/derby/code/trunk/java/engine/org/apache/derby/impl/store/raw/xact/XactFactory.java Thu Mar  8 14:25:41 2007
@@ -218,7 +218,7 @@
 
 	/**
 		Database creation finished
-		@exception StandardException standard cloudscape error policy
+		@exception StandardException standard Derby error policy
 	*/
 	public void createFinished() throws StandardException
 	{
@@ -532,7 +532,7 @@
 
 		Used only in recovery.
 
-		@exception StandardException Cloudscape Standard Error policy
+		@exception StandardException Derby Standard Error policy
 	*/
 	public void handlePreparedXacts(
     RawStoreFactory rsf)
@@ -696,7 +696,7 @@
 		not be allowed to be active during a quiesce state.
 
 
-		@exception StandardException Standard Cloudscape error policy
+		@exception StandardException Standard Derby error policy
 
 	*/
 	protected void pushTransactionContext(ContextManager cm, String contextName, 
@@ -979,7 +979,7 @@
 	 * Return the module providing XAresource interface to the transaction 
      * table. 
      *
 	 * @exception StandardException Standard cloudscape exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()
         throws StandardException
@@ -979,7 +979,7 @@
      * table. 
      *
-	 * @exception StandardException Standard cloudscape exception policy.
+	 * @exception StandardException Standard Derby exception policy.
 	 */
 	public /* XAResourceManager */ Object getXAResourceManager()